@@ -302,11 +302,11 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
     # ensure yarn installs all build tools
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive install --cache-folder %s' % yarn_cache)
+        local('HOME=$(pwd) yarn --production=false --no-progress --non-interactive')
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s' % (options, ngApp))
+            local('HOME=$(pwd) yarn build %s %s' % (options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
